saclib: Computations with real algebraic numbers
================================================

Description
-----------

Saclib is a library of C programs for computer algebra derived from the
SAC2 system. It is mainly used as a dependency of qepcad.

License
-------

ICS :wikipedia:`ISC_license`

Upstream Contact
----------------

- Repository: https://github.com/chriswestbrown/saclib
- Tarballs:   https://www.usna.edu/Users/cs/wcbrown/qepcad/INSTALL/IQ.html
- Website: (outdated) https://www.usna.edu/Users/cs/wcbrown/qepcad/B/QEPCAD.html
